@@ -181,6 +181,7 @@ class ApiGenerator(object):
         models=None,
         domain=None,
         description=None,
+        mode=None,
     ):
         """Constructs an API Generator class that generates API Gateway resources
 
@@ -231,6 +232,7 @@ class ApiGenerator(object):
         self.description = description
         self.shared_api_usage_plan = shared_api_usage_plan
         self.template_conditions = template_conditions
+        self.mode = mode
 
     def _construct_rest_api(self):
         """Constructs and returns the ApiGateway RestApi.
@@ -284,6 +286,9 @@ class ApiGenerator(object):
         if self.description:
             rest_api.Description = self.description
 
+        if self.mode:
+            rest_api.Mode = self.mode
+
         return rest_api
 
     def _construct_body_s3_dict(self):
